<?php
// ----------------------------------------------------------------------
// Language File by VectoR - vector@
vstart.hu
// 
www.vstart.hu
// Updated on: 06/10/2003
// ----------------------------------------------------------------------
// Default time/date formats
define("_TIMEFORMAT","%H:%M");		//%H - hour24, %I - hour12, %M - minute, %p - am/pm
define("_DATEFORMAT","%d. %b");		//%b - month short, %B - month long, %m - month decimal (2 digits),
																	//%a - dayofweek short, %A - dayofweek long, %y - year (2 digits), %Y - year (4 digits)
																	// for more options see http://php.net/strftime

// General Block options
define("_MULTIBLOCK_OPTIONS", "PNphpBB2 MultiBlock Options");
define("_SEP_BAR", "Látszik az elválasztó");
define("_SHOW_TITLE", "Show section title");
define('_USER_STRING_LENGTH','Felhasználónevek maximális hossza (0 = teljes hossz)');
					
// Forum stats
define("_DISPLAY_STATS", "Látszik a Fórum Statisztika");
define("_STATISTICS", "FORUM STATISTICS");
define("_NUMBER_OF_POSTS", "Number of posts");
define("_PTS", "Posts:");
define("_POSTS_PER_DAY", "Posts per day");
define("_PD", "per day:");
define("_NUMBER_TOPICS", "Number of topics");
define("_TOP", "Topics:");
define("_TOPICS_PER_DAY", "Topics per day");
define("_NUMBER_USERS", "Number of users");
define("_USR", "Users:");
define("_USERS_PER_DAY", "Users per day");


// Members Online
define("_DISPLAY_MEMBERS", "Display Members Online in block (Not available in center block)");
if (!defined('_AND'))
{
   define('_AND', 'és');
}
if (!defined('_ONLINE'))
{
   define('_ONLINE', 'online');
}
define('_MEMBERS_ONLINE_TITLE', "Kapcsolatban");
define('_NOMEMBERS','Most nincs tagunk kapcsolatban.');
define('_CURRENTLY','Most');
define('_GUEST','vendég');
define('_GUESTS','vendégünk');
// Added _NOGUESTS to solve translation problems for a few languages.
// Defaults to 0 guests, but can be changed to no in english (currently no guests) and whatever needed for other languages
define('_NOGUESTS','nincs');
define('_MEMBER','tag');
define('_MEMBERS','tagunk');
define('_YOUAREANON','Te most anonymous látogató vagy. A regisztráció és a tagság díjtalan <a href="user.php?op=check_age&module=NS-NewUser"><b>Kattints IDE</b></a>');
define('_USE_PN_PM','Use PostNuke personal message notification');
define('_DISPLAY_TO_ANNON','Display online users to anonymous users');
define("_AMT_PRIVATEMSG","Összes személyes üzenet(ek)!");
define("_UNREAD_PRIVATEMSG"," Olvasatlan személyes üzenet(ek)!");
define("_SEND_PM","Send a private message !");
define("_USE_PM_SOUND", "hang a személyes üzenethez (pnimages/)");
define("_INFO_ICON", "Image to display in anonymous box (pnimages/)");

// Login prompt
define("_DISPLAY_LOGIN", "Bejelntkező ablak tagoknak");
define("_REMEMBER_ME", "Show remember me check box");
define("_REMEMBERME", "Megjegyezzem?");

// Catergory List
define("_DISPLAY_CATEGORY", "Display Category List in block");
define("_CATEGORY_LENGTH" , "Maximal character length of categories");
define("_INCLUDE_CATEGORY", "Show the following categories (CTRL+CLICK clears selections)");
define("_FORUM_DRILLDOWN", "Allow forum drilldown");
define("_FORUM_DRILLDOWN_MAX", "Maximul number of forums to drilldown");
define("_FORUM_CATEGORIES", "Fórumok");

// Last forum Posts
define("_FORUM_POSTS_TITLE", "Utolsó Témák");
define("_DISPLAY_POSTS", "Display Last Forum Posts in block");
define("_DISPLAY_CAT_POSTS", "Display Category with each post");

define("_TIME_FORMAT", "Idő formátuma (PHP)");
define("_DATE_FORMAT", "Dátum formátuma (PHP)");

define("_POST_BY","küldő:");
define("_POST_ON","Hó");
define("_POST_AT","Óra");
define("_GOTO_BOARD","[Fórum Linkje]");
define("_GOTO_POST","goto Post");
define("_BOARD_GUEST","Vendég");
define("_PM_NOTIFICATION","Új személyes üzenet:");

define("_TOPIC_TITLE","Téma");
define("_TOPIC_REPLIES","Válaszok");
define("_TOPIC_VIEWS","Megtekintett");
define("_POSTER","Beküldő");
define("_POST_DATE","Dátum");
define("_POST_TIME","Idő");

define("_LAST_X_POSTS","Number of entries to display");
define("_GROUP_TOPICS","Show only the last post of every topic");
define("_TITLE_STRING_LENGTH","Maximal character length of topic titles & categories (0 = full length)");

define("_EXCLUDE_FORUMS","Don't show posts of the following forums (CTRL+CLICK clears selections)");
define("_MODULE_NAME", "PostNuke module name (Directory name) Default=PNphpBB2");
define("_MODULE_ERROR", "Module name/path is not valid, or module not installed. Please correct.");
define("_PREFIX_ERROR", "Forum prefix error, could not locate forum database.");
define("_TEMPLATE_ERROR","Invalid template settings!");
define("_POSTINFO_ERROR","Unable to obtain post-info from database!");
?>