Charset: iso-8859-1

{MESSAGE}

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The above email was sent to you from {FROM_USERNAME} via his account at {SITENAME}. If this message is spam, contains abusive or other comments you find offensive please contact the webmaster of the board at the following address:

{BOARD_EMAIL}

Include this full email (particularly the headers). Please note that the reply address to this email has been set to that of {FROM_USERNAME}.
