Subject: Új privát üzenete érkezett
Charset: iso-8859-2

Helló {USERNAME},

Új privát üzenete érkezett a "{SITENAME}" fórumon lévő azonosítójára. Az eseményről a korábbiakban értesítést kért. Az új üzenetet megtekintheti az alábbi linkre kattintva:
 
{U_INBOX}

Ne felejtse el, hogy ezeket az értesítéseket letilthatja a Profil menüpontban, a beállítások megváltoztatásával.
 
{EMAIL_SIG}
