Subject: A request to join your group has been made
Charset: iso-8859-2

Kedves {GROUP_MODERATOR},

Egy felhasználó szeretne csatlakozni egy csoporthoz, aminek a moderátora a {SITENAME} fórumon.
A kérés jóváhagyásához vagy visszautasításához keresse fel az alábbi weboldalt:

{U_GROUPCP}

{EMAIL_SIG}

