<?php
/***************************************************************************
 *                            lang_pnphpbb2.php [English]
 *                              -------------------
 *     begin                : Tue Jan 13 2003
 *     update               : Fri Mar 21 2003
 *     copyright            : (C) 2003 the PNphpBB2 Group
 *     email                : support@itsallbutstraw.com
 *
 *     $Id: lang_pnphpbb2.php,v 1.0.0.0 2003/01/13 carls Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//
// The format of this file is ---> $lang['message'] = 'text';
//
// You should also try to set a locale and a character encoding (plus direction). The encoding and direction
// will be sent to the template. The locale may or may not work, it's dependent on OS support and the syntax
// varies ... give it your best guess!
//
//

// Profiles/Registration
$lang['PNphpBB2_Change_Profile'] = 'Change Your PostNuke Profile';
$lang['PNphpBB2_Refresh_Profile'] = 'Refresh Your PostNuke Profile';
$lang['PNphpBB2_Profile_Info'] = 'This information is used in PNphpBB2 only. All profile information that is shared between PostNuke and PNphpBB2 is set in the PostNuke Profile Settings.';
$lang['PNphpBB2_Get_PN_Avatar'] = 'From PostNuke';

// Advanced Quick Reply Mod
$lang['Quick_Reply'] = 'Gyors válasz';
$lang['Quick_quote'] = 'Értékeli az előző hozzászólást';
$lang['Quick_add_smilies'] = 'Ikonok';
$lang['QuoteSelelected'] = 'Értékelés';
$lang['QuoteSelelectedEmpty'] = 'Select a text anywhere on a page and try again';
$lang['Quick_Reply_smilies'] = 'mind';

// Tell-A-Friend Mod
$lang['Tell_Friend'] = "Email a Barátodnak.";
$lang['Tell_Friend_Sender_User'] = "Neved:";
$lang['Tell_Friend_Sender_Email'] = "Email címed:";
$lang['Tell_Friend_Reciever_User'] = "Barátod Neve:";
$lang['Tell_Friend_Reciever_Email'] = "Barátod Email címe:";
$lang['Tell_Friend_Msg'] = "Üzeneted:";
$lang['Tell_Friend_Title'] = "Üzenet egy barátodtól";
$lang['Tell_Friend_Body'] = "Hello,\nI ezt a témát olvastam >>{TOPIC}<< a {SITENAME} portálon. Innen elérheted: {LINK}\n\nGo and read it and if you want to reply you can register for your own account if you have not done so already.";

// Printable Topic
$lang['Print_View'] = "Nyomtatható verzió";

// Credits
$lang['PNphpBB2_Credits_1']  = "Powered by ";
$lang['PNphpBB2_Credits_2'] .= " based on ";
$lang['PNphpBB2_Credits_3'] .= " Group ";
$lang['PNphpBB2_Credits_4'] .= "and by ";
$lang['PNphpBB2_Credits_5'] .= " which uses Theme Graphics by ";
$lang['PNphpBB2_Credits_6'] .= "";
//
// That's all Folks!
// -------------------------------------------------

?>
