Subject: Azonosító aktiválva
Charset: iso-8859-2

Helló {USERNAME},

Az azonosítója a "{SITENAME}" fórumon aktiválva lett, bejelentkezhet azzal a felhasználónévvel és jelszóval, amit a korábbiakban kapott levélben.

{EMAIL_SIG}
