Charset: iso-8859-2

Helló {TO_USERNAME},

A következő üzenetet {FROM_USERNAME} küldte a {SITENAME} fórumon lévő azonosítójával. Ha ez az üzenet spam, sértő, vagy egyéb módon nemkívánatos, vegye fel a kapcsolatot a fórum üzemeltetőivel az alábbi címen:

{BOARD_EMAIL}

Csatolja hozzá ezt a levelet (különösen a levél fejléceit). Megjegyzés: ennek a levélnek a válaszcíme {FROM_USERNAME} címére van beállítva.

Az üzenet a következő:
~~~~~~~~~~~~~~~~~~~~~~

{MESSAGE}

