Subject: A kérése elfogadva
Charset: iso-8859-2

Gratulálunk,

A kérését a "{GROUP_NAME}" csoporthoz való csatlakozáshoz a {SITENAME} fórumon elfogadták.

Csoport tagságáról további információk:
{U_GROUPCP}

{EMAIL_SIG}

