<?php
/***************************************************************************
 *                       lang_pnphpbb2_admin.php [English]
 *                       ---------------------------------
 *     begin                : Tue March 16 2003
 *     update               : Thu March 20 2003
 *     copyright            : (C) 2003 the PNphpBB2 Group
 *     email                : support@pnphpbb.com
 *
 *     $Id: lang_pnphpbb2_admin.php,v 1.0.0.0 2003/01/13 carls Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//
// The format of this file is ---> $lang['message'] = 'text';
//
// You should also try to set a locale and a character encoding (plus direction). The encoding and direction
// will be sent to the template. The locale may or may not work, it's dependent on OS support and the syntax
// varies ... give it your best guess!
//
//

// Installation
$lang['PNphpBB2_Install'] = "PNphpBB2 Installation";
$lang['PNphpBB2_Install_Title'] = "<h4>Installing PNphpBB2 tables to " . $table_prefix . '*</h4>';
$lang['PNphpBB2_Install_Complete'] = '<p><b>PNphpBB2 basic installation is now complete.<br /><br />Click on the "' . $lang['Finish_Install'] . '" to return to the PN module administration page, and activate PNphpBB2.<br /><br />Once activated you can access the forum administration page through the PN administration page (PNphpBB2) or with the link at the bottom of the forum.<br /><br />Please be sure to check the General Configuration details and make any required changes. Thank you for choosing PNphpBB2.</b></p>';

// Update
$lang['PNphpBB2_Upgrade'] = "PNphpBB2 Update";
$lang['PNphpBB2_Move_Tables_No'] = "<p><b>Tables currently exist in " . $table_prefix . "*. The tables located in " . $old_table_prefix . " can not be moved.</b></p>";
$lang['PNphpBB2_Move_Tables_Yes'] = "<h4>Moving tables to new location</h4>";
$lang['PNphpBB2_Move_Complete'] = "<h4>Move complete to " . $table_prefix . "*</h4>";
$lang['PNphpBB2_Database_Type'] = "Database type";
$lang['PNphpBB2_Prev_Version'] = "Previous version &nbsp;:: ";
$lang['PNphpBB2_Upgrade_Version'] = "Updated version &nbsp;:: ";
$lang['PNphpBB2_Update_Schemas'] = "<h4>Updating database schema</h4>";
$lang['PNphpBB2_No_Updates'] =  "<h4>No updates required</h4>";
$lang['PNphpBB2_Update_Data'] = "<h4>Updating data</h4>";
$lang['PNphpBB2_Attach'] = "Attachment Mod Version ";
$lang['PNphpBB2_Updating_Paths'] = "<h4>Updating config table</h4>";
$lang['PNphpBB2_Delete_Themes'] = "<h4>Deleting old themes/style records</h4>";
$lang['PNphpBB2_Install_Themes'] = "<h4>Installing new themes (PNTheme-1, PNLite-2, subSilver-3)</h4>";
$lang['PNphpBB2_Board_Theme'] = "<h4>Setting board default theme to PNTheme</h4>";
$lang['PNphpBB2_User_Theme'] = "<h4>Setting theme for all users to PNTheme</h4>";
$lang['PNphpBB2_Clear_Sessions'] = "<h4>Clearing ALL sessions from sessions table</h4>";
$lang['PNphpBB2_Cant_SQL'] = "<p>CANT CHANGE MSSQL-TABLE. PLEASE DO THE FOLLOWING MANUALLY:<br />IN PHPBB_QUOTA_LIMITS, CHANGE QUOTA_LIMIT TO FROM INT TO BIGINT.</p>";
$lang['PNphpBB2_Update_Complete'] = "<p><b>PNphpBB2 update is now complete.<br /><br />";
$lang['PNphpBB2_Update_Complete'] .= "If you encounter any errors during this process, Please print this page then visit the forums at http://www.pnphpbb.com for support.<br /><br />";
$lang['PNphpBB2_Update_Complete'] .= "Be sure to activate this module before continuing, then review all config settings in the administration page.<br /><br />";
$lang['PNphpBB2_Update_Complete'] .= "If the attachment mod was installed during this process, be sure to enable it if you intend on using it.<br /><br />";
$lang['PNphpBB2_Update_Complete'] .= "Thank you for choosing PNphpBB2</b></p>";
$lang['PNphpBB2_phpBB_Tables_Found'] = "<h5>phpBB_* tables have been found in your PostNuke database. it is VERY important";
$lang['PNphpBB2_phpBB_Tables_Found'] .= "that you understand what this script is about to do. </h5>";
$lang['PNphpBB2_three_options'] = "You have three (3) options at this point.";
$lang['PNphpBB2_option_one'] = "1) Upgrade from a previous version of PNphpBB2 .10b, phpBB2pnmod-203,";
$lang['PNphpBB2_option_one'] .= " phpBB2pnmod-203-Attachments, or phpBB2pnmod-F.";
$lang['PNphpBB2_option_two'] = "2) Upgrade from a stand alone version of phpBB2 (Version 2.0.1-2.0.4)";
$lang['PNphpBB2_option_three'] = "3) Abort conversion";
$lang['PNphpBB2_Upgrade_Disclaimer'] = "PLEASE! Understand that if you choose option two (2), any and ALL users ";
$lang['PNphpBB2_Upgrade_Disclaimer'] .= "will be deleted from your Postnuke database and replaced with the user ";
$lang['PNphpBB2_Upgrade_Disclaimer'] .= "information from the phpBB2 tables</br></br>Once this is done there is NO WAY to turn back from this upgrade, so ";
$lang['PNphpBB2_Upgrade_Disclaimer'] .= "be very sure you have a recent backup of your Postnuke and phpBB2 databases.";
$lang['PNphpBB2_bad_version'] = "Could not obtain version information, or version is older than 2.0.1. Your version is  X$version </br>Please check version information before attempting to continue.</h3>";
$lang['PNphpBB2_Updating_links'] = "Updating post links";

// Removal
$lang['PNphpBB2_Remove_Prompt'] = 'Remove PNphpBB2';
$lang['PNphpBB2_Remove_Text'] = 'Your about to remove PNphpBB2 and all its associated tables from PostNuke (' . $table_prefix . '*).<br /><br />All data will be lost, are you sure you wish to do this?';
$lang['PNphpBB2_Remove_Title'] = "<h4>Removing PNphpBB2 tables from " . $table_prefix . '*</h4>';
$lang['PNphpBB2_Remove_Notes'] = "<p><b>The PNphpBB2 tables have been removed. To complete the removal process, return to the module administration page and remove PNphpBB2 again.</b></p>";

// General
$lang['PNphpBB2_Running'] = "Running";
$lang['PNphpBB2_Failed'] = "FAILED";
$lang['PNphpBB2_ButOK'] = "BUT OK!";
$lang['PNphpBB2_Completed'] = "COMPLETED";
$lang['PNphpBB2_Done'] = "Done";
$lang['PNphpBB2_Aborted'] = "Aborted";
$lang['PNphpBB2_Cancel'] = 'Cancel';
$lang['PNphpBB2_Progress'] = '<h4>Progress</h4>';
$lang['PNphpBB2_Some_Failed'] = "<p><b>Some queries failed, the statements and errors are listing below:<br />(Some action may be needed to add, edit, or remove tables or records)</b></p><br />";
$lang['PNphpBB2_No_Errors'] = "<h4>No errors</h4>";
$lang['PNphpBB2_Results'] = "<h4>Results</h4>";
$lang['PNphpBB2_Installing'] = "Installing";
$lang['PNphpBB2_Updating'] = "Updating";
$lang['PNphpBB2_Important'] = "IMPORTANT";

// Additional administration links
$lang['Users_aguide'] = "<a href=\"" . $pnconfig[sitename] . "/modules/PNphpBB2/docs/attach_user_guide.html\" target=\"_blank\">Users Guide</a>";
$lang['Forum_Manual'] = "<a href=\"" . $pnconfig[sitename] . "/modules/PNphpBB2/docs/phpBB 2_0 User's Guide.htm\" target=\"_blank\">User Manual</a>";

//
// That's all Folks!
// -------------------------------------------------

?>
