Subject: Téma hozzászólás-értesítés - {TOPIC_TITLE}
Charset: iso-8859-2

Helló {USERNAME},

Ezt a levelet azért kapta, mert a {SITENAME} fórumon a "{TOPIC_TITLE}" téma figyelését kérte. A témára válasz érkezett, kattintson az alábbi linkre a válasz megtekintéséhez.
 
{U_TOPIC}

Ha nem kívánja a továbbiakban figyelni ezt a témát, kattintson a "Téma figyelésének megszüntetése" linkre a fenti témánál, vagy keresse fel az alábbi weboldalt:

{U_STOP_WATCHING_TOPIC}

{EMAIL_SIG}
