<?php
// ----------------------------------------------------------------------
// Language file by VectoR vector@vstart.hu www.vstart.hu
// ----------------------------------------------------------------------
define('_TIMEFORMAT','%H:%M');		//%H - hour24, %I - hour12, %M - minute, %p - am/pm
define('_DATEFORMAT','%d. %b');		//%b - month short, %B - month long, %m - month decimal (2 digits),
					//%a - dayofweek short, %A - dayofweek long, %y - year (2 gigits), %Y - year (4 gigits)
					// for more options see http://php.net/strftime

define('_POST_BY','Küldő:');
define('_POST_ON','Dátum:');
define('_POST_AT','Idő:');
define('_GOTO_BOARD',"Link a Fórumhoz");
define('_GOTO_POST','goto Post');
define('_BOARD_GUEST','Vendég');
define('_PM_NOTIFICATION','Új sszemélyes üzenet:');

define('_TOPIC_TITLE','Téma');
define('_TOPIC_REPLIES','Válaszok');
define('_TOPIC_VIEWS','Nézik');
define('_POSTER','Küldő');
define('_POST_DATE','Dátum');
define('_POST_TIME','Idő');

define('_LAST_X_POSTS','Number of entries');
define('_GROUP_TOPICS','Show only the last post of every topic');
define('_TITLE_STRING_LENGTH','Maximal character length of topic titles (0 = full length)');
define('_USER_STRING_LENGTH','Maximal character length of usernames (0 = full length)');
define('_EXCLUDE_FORUMS','Don\'t show posts of the following forums (multiple select possible)');
define('_SELECT_TEMPLATE','Select a template for the output (Note: for center blocks use center templates)');
?>