Subject: Sikeresen csatlakozott a csoporthoz
Charset: iso-8859-2

Gratulálunk,

Sikeresen csatlakozott a "{GROUP_NAME}" csoporthoz a {SITENAME} fórumon.
A csatlakozást a csoport moderátora, vagy a fórum adminisztrátora kezdeményezte. Vegye fel velük a kapcsolatot további információkért.

Csoport tagságáról további információk:
{U_GROUPCP}

{EMAIL_SIG}

