Subject: Üdvözöljük a {SITENAME} fórumán
Charset: iso-8859-2

{WELCOME_MSG}

A COPPA szabályainak értelmében az azonosítója jelenleg inaktív.
 
Kérjük nyomtassa ki az alábbi üzenetet, kérje meg a szüleit vagy gondviselőjét, hogy írja alá, majd küldje el faxon az alábbi címre:

{FAX_INFO}

VAGY küldje el levélben:

{MAIL_INFO}

------------------------------ CUT HERE ------------------------------
Engedély a {SITENAME} fórumhoz való csatlakozáshoz

Felhasználónév: {USERNAME}
Jelszó: {PASSWORD}
Email: {EMAIL_ADDRESS}

ICQ Azonosító: {ICQ}
AIM Cím: {AIM}
MSN Messenger: {MSN}
Yahoo Messenger: {YIM}
Web Site: {WEB_SITE}
Feladó: {FROM}
Foglalkozás: {OCC}
Érdeklődési kör: {INTERESTS}

ELLENŐRIZTEM A GYERMEKEM ÁLTAL MEGADOTT INFORMÁCIÓKAT, ÉS HOZZÁJÁRULOK, HOGY AZ ADATOKAT A {SITENAME} FÓRUMON TÁROLJÁK. 
EGYETÉRTEK AZZAL, HOGY EZEKET AZ ADATOKAT EGY JELSZÓ BEÍRÁSÁVAL BÁRMIKOR MEG LEHET VÁLTOZTATNI. 
EGYETÉRTEK AZZAL, HOGY EZEK AZ ADATOK BÁRMIKOR TÖRÖLHETŐEK A {SITENAME} FÓRUMBÓL.


Szülő vagy Gondviselő
(olvasható név): _____________________

(aláírás): __________________ 

Dátum: _______________

------------------------------ CUT HERE ------------------------------


Amint az adminisztrátorok megkapták a fenti engedélyt faxon vagy postán, az azonosítóját aktiválják.

Kérjük, tartsa emlékezetében a jelszavát, mert az adatbázisunkban kódolva szerepel, így nincs mód a későbbiekben a felderítésére. Természetesen ha elfelejtette, igényelhet helyette egy másikat, amelyet hasonlóképpen aktiválnia kell használat előtt.
 
Köszönjük a regisztrálást!

{EMAIL_SIG}
