Subject: Aktiválja újra az azonosítóját!
Charset: iso-8859-2

Helló {USERNAME},

Az azonosítója a "{SITENAME}" fórumon deaktiválva lett, feltehetőleg azért, mert változtatásokat hajtott végre a profiljában. Az azonosító újra aktiválásához fel kell keresnie az alábbi weboldalt:
 
{U_ACTIVATE}

{EMAIL_SIG}
