Subject: Üdvözöljük a {SITENAME} fórumán
Charset: iso-8859-2

{WELCOME_MSG}

Tartsa meg ezt a levelet, hogy a későbbiekben segítségként felhasználhassa. Az azonosítójának információi az alábbiak:

----------------------------
Felhasználónév: {USERNAME}
Jelszó: {PASSWORD}
----------------------------

Az azonosítója jelenleg inaktív, és a fórum adminisztrátorának aktiválnia kell, mielőtt használni tudná. Amennyiben ez megtörténik, levélben kap róla értesítést.

Kérjük, tartsa emlékezetében a jelszavát, mert az adatbázisunkban kódolva szerepel, így nincs mód a későbbiekben a felderítésére. Természetesen ha elfelejtette, igényelhet helyette egy másikat, amelyet hasonlóképpen aktiválnia kell használat előtt.
 
Köszönjük a regisztrálást!
 
{EMAIL_SIG}
