Charset: iso-8859-2

A következő üzenetet a {SITENAME} fórum egyik adminisztrátora küldte. Ha ez az üzenet spam, sértő, vagy egyéb módon nemkívánatos, vegye fel a kapcsolatot a fórum üzemeltetőivel az alábbi címen:

{BOARD_EMAIL}

Csatolja hozzá ezt a levelet (különösen a levél fejléceit).

Az üzenet a következő:
~~~~~~~~~~~~~~~~~~~~~~

{MESSAGE}

