Subject: Új felhasználói azonosító
Charset: iso-8859-2

Helló,

A "{USERNAME}" azonosító deaktiválva lett, vagy most lett létrehozva. Tekintse meg a felhasználó adatait (ha szükséges) és aktiválja az alábbi weboldal felkeresésével:
 
{U_ACTIVATE}

{EMAIL_SIG}
