Subject: Új jelszó aktiválása
Charset: iso-8859-2

Helló {USERNAME},

Ezt a levelet azért kapta, mert Ön (vagy valaki Ön helyett) új jelszó elküldését kérte a {SITENAME} fórumon lévő azonosítójához. Amennyiben nem kérte ezt az levelet, hagyja figyelmen kívül. Ha a továbbiakban is kapna ilyen leveleket, vegye fel a kapcsolatot a fórum adminisztrátorával.

Az új jelszót aktiválnia kell, mielőtt használni tudná. Az aktiváláshoz keresse fel az alábbi webcímet:

{U_ACTIVATE}

Ha elkészült, be tud jelentkezni az alábbi jelszó használatával:

Jelszó: {PASSWORD}

Természetesen a jelszót meg tudja változtatni a profil beállításainál. Ha segítségre van szüksége, vegye fel a kapcsolatot a fórum adminisztrátorával.

{EMAIL_SIG}
